699bca4f7cfa87c4b5f78cb9c16b442f24251465
angie
  Tue Feb 26 11:26:01 2013 -0800
For Track #7043 (SNPs for mm10): Luvina noticed that mm10.snp137 hasseveral items that use a molType we haven't seen before, "mito";
added filter and color options for that.

diff --git src/hg/lib/snp125Ui.c src/hg/lib/snp125Ui.c
index 50883cf..b067711 100644
--- src/hg/lib/snp125Ui.c
+++ src/hg/lib/snp125Ui.c
@@ -65,51 +65,55 @@
 
 /* As of dbSNP 132, we have some new choices: */
 char *snp132ColorSourceLabels[] = {
     "Class",
     "Validation",
     "Function",
     "Molecule Type",
     "Unusual Conditions (UCSC)",
     "Miscellaneous Attributes (dbSNP)",
     "Allele Frequencies",
 };
 
 int snp132ColorSourceArraySize   = ArraySize(snp132ColorSourceLabels);
 
 /****** MolType related controls *******/
 /* Types: unknown, genomic, cDNA */
 
 char *snp125MolTypeLabels[] = {
     "Unknown",
     "Genomic",
     "cDNA",
+    "Mito"
 };
 char *snp125MolTypeOldColorVars[] = {
     "snp125MolTypeUnknown",
     "snp125MolTypeGenomic",
     "snp125MolTypecDNA",
+    "snp125MolTypeMito",
 };
 char *snp125MolTypeDataName[] = {
     "unknown",
     "genomic",
     "cDNA",
+    "mito"
 };
 char *snp125MolTypeDefault[] = {
     "red",
     "black",
     "blue",
+    "green"
 };
 static char *snp125MolTypeOldIncludeVars[] = {
     "snp125MolTypeUnknownInclude",
@@ -65,51 +65,55 @@
 
 /****** MolType related controls *******/
-/* Types: unknown, genomic, cDNA */
+/* Types: unknown, genomic, cDNA, [rarely] mito */
 
 char *snp125MolTypeLabels[] = {
     "snp125MolTypeGenomicInclude",
     "snp125MolTypecDNAInclude",
 };
 
 int snp125MolTypeArraySize   = ArraySize(snp125MolTypeLabels);
 
 /****** Class related controls *******/
 /* Types: unknown, snp, in-del (locType exact), heterozygous, 
           microsatellite, named, no variation, mixed, mnp, 
 	  insertion (constructed from class = in-del, locType = between)
 	  deletion (constructed from class = in-del, locType = range) */